Texture

Struct Texture 

pub struct Texture {
    pub raw: RawTexture,
    pub bind_group: BindGroup,
}
Texture with a bind group.

This is the typical texture object to be used, as the bind group is needed for applying the texture to rendered objects.

Fields

raw: RawTexturebind_group: BindGroup

Implementations

Source

impl Texture

pub fn update_texture( self, device: &Device, queue: &Queue, bind_group_layout: &BindGroupLayout, rgba: &[u8], height: usize, ) -> Result<Self>

Update the texture with new image.

This function will update the existing buffers if the dimensions match, or create new buffers with new dimensions.

Arguments
  • device - Device of the texture. Must match the original one.
  • queue - Command queue for writing the data. Must match the original one.
  • bind_group_layout - Layout for binding this texture to a shader. Must match the original one.
  • rgba - New image data.
  • height - Height of this image.
pub fn from_rgba_frame( device: &Device, queue: &Queue, bind_group_layout: &BindGroupLayout, label: Option<&'static str>, rgba: &[u8], height: usize, ) -> Result<Self>

Create a texture from RGBA image.

Arguments
  • device - Device to create the texture on.
  • queue - Command queue to write the texture through.
  • bind_group_layout - Layout for binding this texture.
  • label - Optional identification label.
  • rgba - Image data.
  • height - Height of the texture.

Methods from Deref<Target = RawTexture>

pub const DEPTH_FORMAT: TextureFormat = wgpu::TextureFormat::Depth32Float